@@ -99,9 +99,7 @@ class GetHash(object):
 
 
 def script_main(ctx, suffix, check, files, **options):
-    """Generate the main body of the main function."""
-
-    # Build GetHash context.
+    """Generate the main body for the main function."""
     no_stdout = options.pop("no_stdout", False)
     no_stderr = options.pop("no_stderr", False)
     stdout = open(os.devnull, "w") if no_stdout else sys.stdout
@@ -125,12 +123,8 @@ def gethashcli(name):
             is_flag=True,
             help="Read {} from FILES and check them.".format(name),
         )
-        @click.option(
-            "-l", "--start", type=click.INT, help="The start offset of file(s)."
-        )
-        @click.option(
-            "-r", "--stop", type=click.INT, help="The stop offset of file(s)."
-        )
+        @click.option("--start", type=click.INT, help="The start offset of files.")
+        @click.option("--stop", type=click.INT, help="The stop offset of files.")
         @click.option(
             "-d", "--dir", is_flag=True, help="Allow checksum for directories."
         )
@@ -141,6 +135,8 @@ def gethashcli(name):
         @click.option("--no-glob", is_flag=True, help="Do not resolve glob patterns.")
         @click.option("--no-stdout", is_flag=True, help="Do not output to stdout.")
         @click.option("--no-stderr", is_flag=True, help="Do not output to stderr.")
+        @click.option("--tqdm-leave", type=click.BOOL, default=False, show_default=True)
+        @click.option("--tqdm-ascii", type=click.BOOL, default=True, show_default=True)
         @click.version_option(__version__)
         @click.argument("files", nargs=-1)
         @wraps(func)
